@@ -49,4 +49,8 @@ class Bot:
 		try:
 			payload = Gateway().connect(str(self.token), self.intents)
 		except Exception as e:
-			raise InvokeError(e)																										
\ No newline at end of file
+			raise InvokeError(e)		
+			
+bot = Bot(token="Nzg0MTIyMDYxMjE5OTU0NzA4.X8kskw.am004HyFPl2-uwqYioGcCC2ye_s", intents=Intents().all())
+
+bot.run()																								
\ No newline at end of file
