@@ -52,7 +52,7 @@ class HTTPClient:
 		"embed": embed
 		}
 		
-		async with self.__session.post("https://discordapp.com/api/channels/{}/messages".format(channel_id), headers=headers, data = json.dumps(payload))
+		await self.__session.post("https://discordapp.com/api/channels/{}/messages".format(channel_id), headers=headers, data = json.dumps(payload))
 					
 		
 	async def fetch_message(self, channel_id : int, message_id : int):
